PDFLoadProcessor
==========================

.. contents::
    :depth: 1
    :local:
    :backlinks: top


.. automodule:: burdoc.processors.pdf_load_processor


PDFLoadProcessor
----------------

.. autoclass:: burdoc.processors.pdf_load_processor.pdf_load_processor.PDFLoadProcessor
   :members:

PDF Content Handlers
---------------------

.. autoclass:: burdoc.processors.pdf_load_processor.drawing_handler.DrawingHandler
   :members:


.. autoclass:: burdoc.processors.pdf_load_processor.image_handler.ImageHandler
   :members:


.. autoclass:: burdoc.processors.pdf_load_processor.text_handler.TextHandler
   :members: